@@ -12,6 +12,12 @@ import traceback
 import time
 import gettext
 
+try:
+    import pygtk
+    pygtk.require('2.0')
+except ImportError, err:
+    print ("PyGTK not found. Please make sure it is installed properly and referenced in your PYTHONPATH environment variable.")
+
 import gobject
 import gtk
 import gtk.glade
@@ -44,8 +50,8 @@ import glchess.config
 import glchess.ui
 import dialogs
 
-def loadGladeFile(name, root = None, domain = None):
-    return gtk.glade.XML(os.path.join(GLADE_DIR, name), root, domain = domain)
+def loadGladeFile(name, root = None):
+    return gtk.glade.XML(os.path.join(GLADE_DIR, name), root, domain = DOMAIN)
 
 class GtkViewArea(gtk.DrawingArea):
     """Custom widget to render an OpenGL scene"""
@@ -218,17 +224,20 @@ class GtkView(glchess.ui.ViewController):
     """
     """
     # The UI this view belongs to
-    ui            = None
+    ui               = None
     
     # The title of this view
-    title         = None
+    title            = None
     
     # The widget to render the scene to
-    widget        = None
+    widget           = None
     
     # A Gtk+ tree model to store the move history
-    moveModel    = None
-    selectedMove = -1
+    moveModel        = None
+    selectedMove     = -1
+    
+    # Flag to show if requesting attention
+    requireAttention = False
     
     def __init__(self, ui, title, feedback, isActive = True):
         """Constructor for a view.
@@ -255,7 +264,17 @@ class GtkView(glchess.ui.ViewController):
     def render(self):
         """Extends glchess.ui.ViewController"""
         self.widget.redraw()
-        
+
+    def setAttention(self, requiresAttention):
+        """Extends glchess.ui.ViewController"""
+        if self.requireAttention == requiresAttention:
+            return
+        self.requireAttention = requiresAttention
+        if requiresAttention:
+            self.ui._incAttentionCounter(1)
+        else:
+            self.ui._incAttentionCounter(-1)
+
     def addMove(self, move):
         """Extends glchess.ui.ViewController"""
         # FIXME: Make a '@ui' player who watches for these itself?
@@ -272,6 +291,8 @@ class GtkView(glchess.ui.ViewController):
     
     def close(self):
         """Extends glchess.ui.ViewController"""
+        if self.requireAttention:
+            self.ui._incAttentionCounter(-1)
         self.ui._removeView(self)
     
     # Public methods
@@ -428,7 +449,7 @@ class AIView:
         """
         """
         self.window = window
-        self.__gui = loadGladeFile('ai.glade', 'ai_table', domain = 'glchess')
+        self.__gui = loadGladeFile('ai.glade', 'ai_table')
         self.__gui.get_widget('executable_label').set_text(executable)
         self.__gui.get_widget('game_label').set_text(description)
 
@@ -514,41 +535,43 @@ class GtkUI(glchess.ui.UI):
     """
     """
     # The Gtk+ GUI
-    _gui              = None
+    _gui               = None
     
     # The time stored for animation
-    __lastTime        = None
-    __animationTimer  = None
+    __lastTime         = None
+    __animationTimer   = None
 
     # The notebook containing games
-    notebook        = None
-    
+    notebook           = None
+
     # The Gtk+ list model of the available player types
-    __playerModel     = None
-    
+    __playerModel      = None
+
     # The about dialog open
-    __aboutDialog     = None
-    
+    __aboutDialog      = None
+
     # Dictionary of save game dialogs keyed by view
-    __saveGameDialogs = None
-    
-    __renderGL        = False
-    openGLInfoPrinted = False
+    __saveGameDialogs  = None
+
+    __renderGL         = False
+    openGLInfoPrinted  = False
 
     # TODO
-    __joinGameDialogs = None
-    __networkGames    = None
-    
-    __defaultWhiteAI  = None
-    __defaultBlackAI  = None
+    __joinGameDialogs  = None
+    __networkGames     = None
     
+    __defaultWhiteAI   = None
+    __defaultBlackAI   = None
+
+    __attentionCounter = 0
+
     def __init__(self):
         """Constructor for a GTK+ glChess GUI"""
         self.__networkGames = {}
         self.__saveGameDialogs = {}
         self.__joinGameDialogs = []
         
-        self._gui = loadGladeFile('glchess.glade', domain = 'glchess')
+        self._gui = loadGladeFile('glchess.glade')
         self._gui.signal_autoconnect(self)
 
         # Make a notebook for the games
@@ -576,10 +599,10 @@ class GtkUI(glchess.ui.UI):
         combo.add_attribute(cell, 'text', 1)
 
         self.defaultViewController = self.notebook.setDefault(None)
-        
-        # Disable OpenGL support
-        if not hasattr(gtk, 'gtkgl'):
-            self._gui.get_widget('menu_view_3d').set_sensitive(False)
+
+        # Disble help support
+        if haveGnomeSupport:
+            self._gui.get_widget('menu_help').show()
         
         self.defaultViewController.widget.setRenderGL(self.__renderGL)
 
@@ -692,6 +715,22 @@ class GtkUI(glchess.ui.UI):
             dialog.removeNetworkGame(game)
 
     # Protected methods
+    
+    def _incAttentionCounter(self, offset):
+        """
+        """
+        self.__attentionCounter += offset
+        self.__updateAttention()
+        
+    def __updateAttention(self):
+        """
+        """
+        widget = self._gui.get_widget('glchess_app')
+        widget.set_urgency_hint(self.__attentionCounter != 0 and not widget.is_active())
+        
+    def _on_focus_changed(self, widget, data = None):
+        """Gtk+ callback"""
+        self.__updateAttention()
 
     def _saveView(self, view, path):
         """
@@ -728,7 +767,7 @@ class GtkUI(glchess.ui.UI):
         if name == 'width' or name == 'height':
             self.__resize()
             return
-        
+
         # Show/hide the toolbar
         if name == 'show_toolbar':
             toolbar = self.__getWidget('toolbar')
@@ -764,7 +803,11 @@ class GtkUI(glchess.ui.UI):
                 self._gui.get_widget('menu_fullscreen').show()
 
         # Enable/disable OpenGL rendering
-        elif name == 'show_3d':
+        elif name == 'show_3d':            
+            if value and not haveGLSupport:
+                self._gui.get_widget('3d_support_dialog').show()
+                glchess.config.set('show_3d', False)
+                value = False
             self.__renderGL = value
             menuItem = self.__getWidget('menu_view_3d')
             menuItem.set_active(self.__renderGL)
@@ -900,6 +943,14 @@ class GtkUI(glchess.ui.UI):
 
     def _on_view_changed(self, widget, page, pageNum, data = None):
         """Gtk+ callback"""
+        # Set the window title to the name of the game
+        view = self.notebook.getView()
+        title = gettext.gettext('Chess')
+        if view is not None:
+            title += " - %s" % view.title
+        self._gui.get_widget('glchess_app').set_title(title)
+        
+        # Set toolbar/menu buttons to state for this game
         self._updateViewButtons()
     
     def _updateViewButtons(self):
@@ -927,8 +978,7 @@ class GtkUI(glchess.ui.UI):
 
     def _on_new_game_button_clicked(self, widget, data = None):
         """Gtk+ callback"""
-        
-        dialogs.GtkNewGameDialog(self, self.__playerModel, whiteAI = self.__defaultWhiteAI, blackAI = self.__defaultBlackAI)
+        dialogs.GtkNewGameDialog(self, self.__playerModel)
 
     def _on_join_game_button_clicked(self, widget, data = None):
         """Gtk+ callback"""
@@ -977,6 +1027,18 @@ class GtkUI(glchess.ui.UI):
     def _on_view_unfullscreen_clicked(self, widget, data = None):
         """Gtk+ callback"""
         glchess.config.set('fullscreen', False)
+        
+    def _on_3d_support_dialog_delete_event(self, widget, data = None):
+        """Gtk+ callback"""
+        # Stop the dialog from deleting itself
+        return True
+        
+    def _on_3d_support_dialog_response(self, widget, data = None):
+        """Gtk+ callback"""
+        if self.__aboutDialog is not None:
+            return
+        widget.hide()
+        return False
 
     def _on_about_clicked(self, widget, data = None):
         """Gtk+ callback"""
@@ -992,11 +1054,13 @@ class GtkUI(glchess.ui.UI):
         dialog.set_comments(DESCRIPTION)
         dialog.set_authors(AUTHORS)
         dialog.set_artists(ARTISTS)
-        dialog.set_translator_credits(TRANSLATORS)
+        string = ''
+        for t in TRANSLATORS:
+            string += t + '\n'
+        dialog.set_translator_credits(string[:-1])
         dialog.set_website(WEBSITE)
         dialog.set_website_label(WEBSITE_LABEL)
         dialog.set_logo_icon_name('glchess')
-        dialog.set_translator_credits(TRANSLATORS)
         dialog.connect('response', self._on_glchess_about_dialog_close)
         dialog.show()
         
