@@ -21,6 +21,7 @@ import game
 import chess.board
 import chess.lan
 import ai
+from defaults import *
 
 #import dbus.glib
 #import network
@@ -86,9 +87,10 @@ class HumanPlayer(game.ChessPlayer):
         """
         game.ChessPlayer.__init__(self, name)
         self.__game = chessGame
-        
+
     def readyToMove(self):
         # FIXME: ???
+        self.__game.view.controller.setAttention(True)
         self.__game.scene.setHumanPlayer(self)
         self.__game.cairoScene.setHumanPlayer(self)
 
@@ -96,14 +98,14 @@ class AIPlayer(ai.Player):
     """
     """
     
-    def __init__(self, application, name, profile, description):
+    def __init__(self, application, name, profile, level, description):
         """
         """
         executable = profile.path
         for arg in profile.arguments[1:]:
             executable += ' ' + arg
         self.window = application.ui.addAIWindow(profile.name, executable, description)
-        ai.Player.__init__(self, name, profile)
+        ai.Player.__init__(self, name, profile, level)
         
     def logText(self, text, style):
         """Called by ai.Player"""
@@ -244,6 +246,7 @@ class SceneCairo(scene.cairo.Scene, scene.human.SceneHumanInput):
             colour = chess.board.BLACK
         move = chess.lan.encode(colour, start, end, promotionType = chess.board.QUEEN) # FIXME: Promotion type
         player.move(move)
+        self.__game.view.controller.setAttention(False)
 
 class SceneOpenGL(scene.opengl.Scene, scene.human.SceneHumanInput):
     """
@@ -384,6 +387,7 @@ class SceneOpenGL(scene.opengl.Scene, scene.human.SceneHumanInput):
             colour = chess.board.BLACK
         move = chess.lan.encode(colour, start, end, promotionType = chess.board.QUEEN) # FIXME: Promotion type
         player.move(move)
+        self.__game.view.controller.setAttention(False)
 
 class Splashscreen(ui.ViewFeedback):
     """
@@ -468,14 +472,20 @@ class View(ui.ViewFeedback):
         self.game.scene.setMoveNumber(moveNumber)
         self.game.cairoScene.setMoveNumber(moveNumber)
         
-    def save(self, filename):
+    def save(self, fileName = None):
         """Called by ui.ViewFeedback"""
+        if fileName is None:
+            fileName = self.game.fileName
+            assert(fileName is not None)
+
         try:
-            f = file(filename, 'w')
+            f = file(fileName, 'w')
         except IOError, e:
-            self.reportError('Unable to save PGN file ' + filename, str(e))
+            self.game.application.ui.reportError('Unable to save PGN file %s' % fileName, e.args[1])
             return
         
+        print 'Saving game ' + repr(self.game.name) + ' to ' + fileName
+
         pgnGame = chess.pgn.PGNGame()
         self.game.toPGN(pgnGame)
             
@@ -484,6 +494,17 @@ class View(ui.ViewFeedback):
             f.write(line + '\n')
         f.write('\n')
         f.close()
+        
+        self.game.fileName = fileName
+        self.game.needsSaving = False
+        
+    def getFileName(self):
+        """Called by ui.ViewFeedback"""
+        return self.game.fileName
+        
+    def needsSaving(self):
+        """Called by ui.ViewFeedback"""
+        return self.game.needsSaving and (self.game.fileName is not None)
 
     def close(self):
         """Called by ui.ViewFeedback"""
@@ -497,7 +518,7 @@ class ChessGame(game.ChessGame):
     application    = None
     
     # The name of the game
-    __name         = None
+    name           = None
     
     # The scene for this game
     scene          = None
@@ -509,6 +530,10 @@ class ChessGame(game.ChessGame):
     __movePlayer   = None
     __aiPlayers    = None
     __humanPlayers = None
+    
+    # The file this is saved to
+    fileName       = None
+    needsSaving    = True
 
     def __init__(self, application, name):
         """Constructor for a chess game.
@@ -517,7 +542,7 @@ class ChessGame(game.ChessGame):
         'name' is the name of the game (string).
         """
         self.application = application
-        self.__name = name
+        self.name = name
         self.__aiPlayers = []
         self.__humanPlayers = []
         
@@ -534,20 +559,17 @@ class ChessGame(game.ChessGame):
         self.__movePlayer = MovePlayer(self)
         self.addSpectator(self.__movePlayer)
 
-    def getName(self):
-        """Returns the name of the game (string)"""
-        return self.__name
-    
-    def addAIPlayer(self, name, profile):
+    def addAIPlayer(self, name, profile, level):
         """Create an AI player.
         
         'name' is the name of the player to create (string).
         'profile' is the the AI profile to use (ai.Profile).
+        'level' is the difficulty level to use (string).
         
         Returns an AI player to use (game.ChessPlayer).
         """
-        description = "'" + name + "' in '" + self.__name + "'"
-        player = AIPlayer(self.application, name, profile, description)
+        description = "'" + name + "' in '" + self.name + "'"
+        player = AIPlayer(self.application, name, profile, level, description)
         self.__aiPlayers.append(player)
         self.application.watchAIPlayer(player)
         return player
@@ -586,14 +608,19 @@ class ChessGame(game.ChessGame):
         white = self.getWhite()
         black = self.getBlack()
         
-        pgnGame.setTag(pgnGame.PGN_TAG_EVENT, self.getName())
+        pgnGame.setTag(pgnGame.PGN_TAG_EVENT, self.name)
         pgnGame.setTag(pgnGame.PGN_TAG_WHITE, white.getName())
         pgnGame.setTag(pgnGame.PGN_TAG_BLACK, black.getName())
 
+        # FIXME: AI levels
         if isinstance(white, ai.Player):
-            pgnGame.setTag('WhiteAI', white.getProfile().name)
+            (profile, level) = white.getProfile()
+            pgnGame.setTag('WhiteAI', profile)
+            pgnGame.setTag('WhiteLevel', level)
         if isinstance(black, ai.Player):
-            pgnGame.setTag('BlackAI', black.getProfile().name)
+            (profile, level) = black.getProfile()
+            pgnGame.setTag('BlackAI', profile)
+            pgnGame.setTag('BlackLevel', level)
 
         moves = self.getMoves()
         while len(moves) > 0:
@@ -630,6 +657,7 @@ class ChessGame(game.ChessGame):
     def _onPlayerMoved(self, player, move):
         """FIXME: Rename this
         """
+        self.needsSaving = True
         self.view.controller.addMove(move)
 
 class UI(gtkui.GtkUI):
@@ -662,58 +690,30 @@ class UI(gtkui.GtkUI):
             player.read()
             return True
 
-    def onGameStart(self, gameName, allowSpectators, whiteName, whiteType, blackName, blackType, moves = None):
+    def onGameStart(self, gameName, allowSpectators, duration, white, black):
         """Called by UI"""
-        g = self.__application.addGame(gameName, whiteName, whiteType, blackName, blackType)
-        print 'Starting game ' + gameName + ' between ' + whiteName + '(' + str(whiteType) + ') and ' + blackName + '(' + str(blackType) + ')'
-        if moves:
-            g.start(moves)
+        if white.type is ui.HUMAN:
+            w = None
         else:
-            g.start()
+            w = (white.type, white.level)
+        if black.type is ui.HUMAN:
+            b = None
+        else:
+            b = (black.type, black.level)
+        g = self.__application.addGame(gameName, white.name, w, black.name, b)
+        print 'Starting game ' + gameName + ' between ' + white.name + '(' + str(white.type) + ') and ' + black.name + '(' + str(black.type) + ')'
+        g.start()
         
-    def loadGame(self, path, returnResult):
+    def loadGame(self, path):
         """Called by ui.UI"""
         try:
             p = chess.pgn.PGN(path, 1)
         except chess.pgn.Error, e:
-            self.reportError('Unable to open PGN file ' + path, str(e))
+            self.reportError('Unable to open PGN file %s' % path, e.description)
             return
         
         # Use the first game
-        pgnGame = p[0]
-        
-        if returnResult is True:
-            whiteAI = pgnGame.getTag('WhiteAI')
-            blackAI = pgnGame.getTag('BlackAI')
-            msg = ''
-            if whiteAI and self.__application.getAIProfile(whiteAI) is None:
-                msg += "AI '" + whiteAI + "' is not installed, white player is now human"
-                whiteAI = None
-            if blackAI and self.__application.getAIProfile(blackAI) is None:
-                if msg != '':
-                    msg += '\n'
-                msg += "AI '" + blackAI + "' is not installed, black player is now human"
-                blackAI = None
-
-            self.reportGameLoaded(gameName = pgnGame.getTag(pgnGame.PGN_TAG_EVENT),
-                                  whiteName = pgnGame.getTag(pgnGame.PGN_TAG_WHITE),
-                                  blackName = pgnGame.getTag(pgnGame.PGN_TAG_BLACK),
-                                  whiteAI = whiteAI, blackAI = blackAI,
-                                  moves = pgnGame.getMoves())
-                                  
-            if len(msg) > 0:
-                self.reportError('Game modified', msg)
-        else:
-            g = self.__application.addPGNGame(pgnGame)
-            moves = pgnGame.getMoves()
-            if moves:
-                g.start(moves)
-            else:
-                g.start()
-
-    def onGameJoin(self, localName, localType, game):
-        """Called by UI"""
-        print 'Joining game ' + str(game) + ' as ' + localName + '(' + str(localType) + ')'
+        self.__application.addPGNGame(p[0], path)
 
     def onQuit(self):
         """Called by UI"""
@@ -796,7 +796,7 @@ class Application:
         """
         self.aiPlayers[player.fileno()] = player
         self.ui.watchFileDescriptor(player.fileno())
-        
+
     def unwatchAIPlayer(self, player):
         """
         """
@@ -807,12 +807,14 @@ class Application:
         
         'name' is the name of the game (string).
         'whiteName' is the name of the white player (string).
-        'whiteType' is the AI profile to use for white (string) or None if white is human.
+        'whiteType' is a 2-tuple containing the AI profile name and difficulty level (str, str) or None for human players.
         'blackName' is the name of the black player (string).
-        'blackType' is the AI profile to use for black (string) or None if black is human.
+        'blackType' is a 2-tuple containing the AI profile name and difficulty level (str, str) or None for human players.
         
         Returns the game object. Use game.start() to start the game.
         """
+        # FIXME: Replace arguments with player objects
+        
         # Create the game
         g = ChessGame(self, name)
         self.__games.append(g)
@@ -821,23 +823,27 @@ class Application:
         if whiteType is None:
             player = g.addHumanPlayer(whiteName)
         else:
+            (profileName, level) = whiteType
             try:
-                profile = self.__aiProfiles[whiteType]
-                player = g.addAIPlayer(whiteName, profile)
+                profile = self.__aiProfiles[profileName]
             except KeyError:
                 msg += "AI '" + whiteType + "' is not installed, white player is now human"
                 player = g.addHumanPlayer(whiteName)
+            else:
+                player = g.addAIPlayer(whiteName, profile, level)
         g.setWhite(player)
 
         if blackType is None:
             player = g.addHumanPlayer(blackName)
         else:
+            (profileName, level) = blackType
             try:
-                profile = self.__aiProfiles[blackType]
-                player = g.addAIPlayer(blackName, profile)
+                profile = self.__aiProfiles[profileName]
             except KeyError:
                 msg += "AI '" + blackType + "' is not installed, black player is now human"
                 player = g.addHumanPlayer(blackName)
+            else:
+                player = g.addAIPlayer(blackName, profile, level)
         g.setBlack(player)
                 
         if len(msg) > 0:
@@ -845,19 +851,47 @@ class Application:
 
         return g
     
-    def addPGNGame(self, pgnGame):
+    def addPGNGame(self, pgnGame, path):
         """Add a PGN game.
         
         'pgnGame' is the game to add (chess.pgn.PGNGame).
+        'path' is the path this game was loaded from (string or None).
         
         Returns the game object. Use game.start() to start the game.
         """
-        return self.addGame(pgnGame.getTag(pgnGame.PGN_TAG_EVENT),
-                            pgnGame.getTag(pgnGame.PGN_TAG_WHITE),
-                            pgnGame.getTag('WhiteAI'),
-                            pgnGame.getTag(pgnGame.PGN_TAG_BLACK),
-                            pgnGame.getTag('BlackAI'))
-                            
+        whiteType = pgnGame.getTag('WhiteAI')
+        if whiteType is None:
+            w = None
+        else:
+            level = pgnGame.getTag('WhiteLevel')
+            if level is None:
+                level = 'normal'
+            w = (whiteType, level)
+
+        blackType = pgnGame.getTag('BlackAI')
+        if blackType is None:
+            b = None
+        else:
+            level = pgnGame.getTag('BlackLevel')
+            if level is None:
+                level = 'normal'
+            b = (blackType, level)
+
+        g = self.addGame(pgnGame.getTag(pgnGame.PGN_TAG_EVENT),
+                         pgnGame.getTag(pgnGame.PGN_TAG_WHITE), w,
+                         pgnGame.getTag(pgnGame.PGN_TAG_BLACK), b)
+        g.fileName = path
+        moves = pgnGame.getMoves()
+        if moves:
+            g.start(moves)
+        else:
+            g.start()
+            
+        # No change from when loaded
+        g.needsSaving = False
+
+        return g
+
     def addMove(self, view, move):
         # TEMP
         self.ui.addMove(view, move)
@@ -867,7 +901,7 @@ class Application:
         
         This method does not return.
         """
-        print 'This is glChess 2.17.1'
+        print 'This is glChess ' + VERSION
         
         # Load AI profiles
         profiles = ai.loadProfiles()
@@ -884,27 +918,17 @@ class Application:
         if nArgs == 1:
             self.__autoload()
         
-        # Load requested game
-        # TODO: Merge this with the UI requested load games
-        elif nArgs == 2:
-            path = sys.argv[1]
+        # Load requested games
+        for path in sys.argv[1:]:
             try:
                 p = chess.pgn.PGN(path, 1)
             except chess.pgn.Error, e:
                 # TODO: Pop-up dialog
-                print e
+                print 'Unable to open PGN file ' + path + ':' + str(e)
             else:
                 # Use the first game
-                pgnGame = p[0]
-                g = self.addPGNGame(pgnGame)
-                moves = pgnGame.getMoves()
-                if moves:
-                    g.start(moves)
-                else:
-                    g.start()
-        else:
-            print 'Usage: ' + sys.argv[0] + ' [PGN file]'
-            sys.exit()
+                if len(p) > 0:
+                    g = self.addPGNGame(p[0], path)
 
         # Start UI (does not return)
         try:
@@ -927,7 +951,7 @@ class Application:
 
     def quit(self):
         """Quit glChess"""
-        # Save any open games
+        # Save any games not saved to a file
         self.__autosave()
         
         # End current games (will delete AIs etc)
@@ -967,8 +991,7 @@ class Application:
 
         # Restore each game
         for pgnGame in games:
-            g = self.addPGNGame(pgnGame)
-            g.start(pgnGame.getMoves())
+            self.addPGNGame(pgnGame, None)
     
     def __autosave(self):
         """Save any open games to the autosave file"""
@@ -980,6 +1003,10 @@ class Application:
         
         f = file(fname, 'a')
         for g in self.__games:
+            # Ignore games that are saved to a file
+            if g.fileName is not None:
+                continue
+            
             pgnGame = chess.pgn.PGNGame()
             g.toPGN(pgnGame)
             
@@ -990,6 +1017,5 @@ class Application:
         f.close()
 
 if __name__ == '__main__':
-    gettext.textdomain('gnome-games')
     app = Application()
     app.start()
