@@ -73,9 +73,9 @@ struct _GnobotsProperties {
   gboolean splats;
   gboolean show_toolbar;
   GdkColor bgcolour;
-  gint     selected_config;
-  gint     keys[12];
-  gchar    *themename;
+  gint selected_config;
+  gint keys[12];
+  gchar *themename;
 };
 /**********************************************************************/
 
@@ -83,17 +83,18 @@ struct _GnobotsProperties {
 /**********************************************************************/
 /* File Static Variables                                              */
 /**********************************************************************/
-static GtkWidget         *propbox      = NULL;
+static GtkWidget *propbox = NULL;
 
-static GamesFileList     *theme_list   = NULL;
+static GamesFileList *theme_list = NULL;
 
-static GnobotsProperties  properties;
+static GnobotsProperties properties;
 
 static gint default_keys[12] = {
-  GDK_KP_7, GDK_KP_8, GDK_KP_9, 
+  GDK_KP_7, GDK_KP_8, GDK_KP_9,
   GDK_KP_4, GDK_KP_5, GDK_KP_6,
   GDK_KP_1, GDK_KP_2, GDK_KP_3,
-  GDK_KP_Add, GDK_KP_Multiply, GDK_KP_Enter};
+  GDK_KP_Add, GDK_KP_Multiply, GDK_KP_Enter
+};
 
 
 static GConfClient *gconf_client;
@@ -105,15 +106,15 @@ static GConfClient *gconf_client;
 /* Function Prototypes                                                */
 /**********************************************************************/
 static void apply_changes (void);
-static void apply_cb (GtkWidget*, gpointer);
-static gboolean delete_cb (GtkWidget*, gpointer);
-static void pmap_selection (GtkWidget*, gpointer);
-static void type_selection (GtkWidget*, gpointer);
-static void safe_cb (GtkWidget*, gpointer);
-static void sound_cb (GtkWidget*, gpointer);
-static void splat_cb (GtkWidget*, gpointer);
-static void defkey_cb (GtkWidget*, gpointer);
-static void fill_typemenu (GtkWidget*);
+static void apply_cb (GtkWidget *, gpointer);
+static gboolean delete_cb (GtkWidget *, gpointer);
+static void pmap_selection (GtkWidget *, gpointer);
+static void type_selection (GtkWidget *, gpointer);
+static void safe_cb (GtkWidget *, gpointer);
+static void sound_cb (GtkWidget *, gpointer);
+static void splat_cb (GtkWidget *, gpointer);
+static void defkey_cb (GtkWidget *, gpointer);
+static void fill_typemenu (GtkWidget *);
 static void gconf_set_background_color (GdkColor * c);
 /**********************************************************************/
 
@@ -147,7 +148,7 @@ apply_changes (void)
  * TRUE if the event was handled
  **/
 static void
-apply_cb (GtkWidget *w, gpointer data)
+apply_cb (GtkWidget * w, gpointer data)
 {
   apply_changes ();
 
@@ -165,14 +166,15 @@ apply_cb (GtkWidget *w, gpointer data)
  * handles property-box destruction messages
  **/
 static gboolean
-delete_cb (GtkWidget *w, gpointer data)
+delete_cb (GtkWidget * w, gpointer data)
 {
   propbox = NULL;
 
   return FALSE;
 }
 
-gint save_window_geometry (GtkWidget *w, GdkEventConfigure *e, gpointer data)
+gint
+save_window_geometry (GtkWidget * w, GdkEventConfigure * e, gpointer data)
 {
   gconf_client_set_int (gconf_client, KEY_WINDOW_WIDTH, e->width, NULL);
   gconf_client_set_int (gconf_client, KEY_WINDOW_HEIGHT, e->height, NULL);
@@ -180,7 +182,8 @@ gint save_window_geometry (GtkWidget *w, GdkEventConfigure *e, gpointer data)
   return FALSE;
 }
 
-void set_window_geometry (GtkWidget *window)
+void
+set_window_geometry (GtkWidget * window)
 {
   int w, h;
 
@@ -199,7 +202,7 @@ void set_window_geometry (GtkWidget *window)
  * handles pixmap selection messages
  **/
 static void
-pmap_selection (GtkWidget *widget, gpointer data)
+pmap_selection (GtkWidget * widget, gpointer data)
 {
   gint n;
 
@@ -224,7 +227,7 @@ pmap_selection (GtkWidget *widget, gpointer data)
  * handles configuration selection messages
  **/
 static void
-type_selection (GtkWidget *widget, gpointer data)
+type_selection (GtkWidget * widget, gpointer data)
 {
   gint num = gtk_combo_box_get_active (GTK_COMBO_BOX (widget));
 
@@ -247,7 +250,7 @@ type_selection (GtkWidget *widget, gpointer data)
  * handles message from the 'safe moves' checkbox
  **/
 static void
-safe_cb (GtkWidget *widget, gpointer data)
+safe_cb (GtkWidget * widget, gpointer data)
 {
   properties.safe_moves = GTK_TOGGLE_BUTTON (widget)->active;
   gconf_set_use_safe_moves (properties.safe_moves);
@@ -263,7 +266,7 @@ safe_cb (GtkWidget *widget, gpointer data)
  * handles message from the 'super_safe moves' checkbox
  **/
 static void
-super_safe_cb (GtkWidget *widget, gpointer data)
+super_safe_cb (GtkWidget * widget, gpointer data)
 {
   properties.super_safe_moves = GTK_TOGGLE_BUTTON (widget)->active;
   gconf_set_use_super_safe_moves (properties.super_safe_moves);
@@ -279,7 +282,7 @@ super_safe_cb (GtkWidget *widget, gpointer data)
  * handles message from the 'sound' checkbox
  **/
 static void
-sound_cb (GtkWidget *widget, gpointer data)
+sound_cb (GtkWidget * widget, gpointer data)
 {
   properties.sound = GTK_TOGGLE_BUTTON (widget)->active;
   gconf_set_enable_sound (properties.sound);
@@ -295,7 +298,7 @@ sound_cb (GtkWidget *widget, gpointer data)
  * handles message from the 'splat' checkbox
  **/
 static void
-splat_cb (GtkWidget *widget, gpointer data)
+splat_cb (GtkWidget * widget, gpointer data)
 {
   properties.splats = GTK_TOGGLE_BUTTON (widget)->active;
   gconf_set_enable_splats (properties.splats);
@@ -311,12 +314,12 @@ splat_cb (GtkWidget *widget, gpointer data)
  * handles message from the default key buttons
  **/
 static void
-defkey_cb (GtkWidget *widget, gpointer data)
+defkey_cb (GtkWidget * widget, gpointer data)
 {
   gint i;
-  gint *dkeys = (gint*)data;
+  gint *dkeys = (gint *) data;
 
-  for (i = 0; i < 12; ++i){
+  for (i = 0; i < 12; ++i) {
     properties.keys[i] = dkeys[i];
     gconf_set_control_key (i, keyboard_string (properties.keys[i]));
   }
@@ -332,7 +335,7 @@ defkey_cb (GtkWidget *widget, gpointer data)
  * fills the listbox with configuration names
  **/
 static void
-fill_typemenu (GtkWidget *menu)
+fill_typemenu (GtkWidget * menu)
 {
   gint i;
 
@@ -340,7 +343,7 @@ fill_typemenu (GtkWidget *menu)
   /* this is just a place holder so that xgettext can found the strings to
    * translate (those are the default games types)
    */
-  char *just_a_place_holder[]={ 
+  char *just_a_place_holder[] = {
     N_("classic robots"),
     N_("robots2"),
     N_("robots2 easy"),
@@ -349,7 +352,7 @@ fill_typemenu (GtkWidget *menu)
   };
 #endif
 
-  for (i = 0; i < num_game_configs (); ++i){
+  for (i = 0; i < num_game_configs (); ++i) {
     gtk_combo_box_append_text (GTK_COMBO_BOX (menu), _(game_config_name (i)));
   }
 
@@ -380,7 +383,7 @@ make_theme_menu (void)
   /* this is just a place holder so that xgettext can found the strings to
    * translate (those are the default graphic styles)
    */
-  char *just_a_place_holder[]={
+  char *just_a_place_holder[] = {
     N_("robots"),
     N_("cows"),
     N_("eggs"),
@@ -391,17 +394,17 @@ make_theme_menu (void)
   };
 #endif
 
-  return games_file_list_create_widget (theme_list, 
+  return games_file_list_create_widget (theme_list,
 					properties.themename,
 					GAMES_FILE_LIST_REMOVE_EXTENSION |
 					GAMES_FILE_LIST_REPLACE_UNDERSCORES);
 }
 
 static void
-bg_color_callback (GtkWidget *widget, gpointer data)
+bg_color_callback (GtkWidget * widget, gpointer data)
 {
   gtk_color_button_get_color (GTK_COLOR_BUTTON (widget),
-                              &properties.bgcolour);  
+			      &properties.bgcolour);
   set_background_color (properties.bgcolour);
   clear_game_area ();
   gconf_set_background_color (&properties.bgcolour);
@@ -419,7 +422,7 @@ properties_theme_name (void)
  * Description:
  * displays the properties dialog
  **/
-void 
+void
 show_properties_dialog (void)
 {
   GtkWidget *notebook;
@@ -439,27 +442,27 @@ show_properties_dialog (void)
   GtkWidget *controls_list;
   GtkTooltips *tooltips;
 
-  if (propbox) 
+  if (propbox)
     return;
 
   tooltips = gtk_tooltips_new ();
 
   propbox = gtk_dialog_new_with_buttons (_("Robots Preferences"),
-                                         GTK_WINDOW  (app),
-                                         GTK_DIALOG_DESTROY_WITH_PARENT,
-                                         GTK_STOCK_CLOSE, GTK_RESPONSE_ACCEPT,
-                                         NULL);
+					 GTK_WINDOW (app),
+					 GTK_DIALOG_DESTROY_WITH_PARENT,
+					 GTK_STOCK_CLOSE, GTK_RESPONSE_ACCEPT,
+					 NULL);
   gtk_dialog_set_has_separator (GTK_DIALOG (propbox), FALSE);
   gtk_container_set_border_width (GTK_CONTAINER (propbox), 5);
   gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (propbox)->vbox), 2);
   /* Set up notebook and add it to hbox of the gtk_dialog */
   g_signal_connect (G_OBJECT (propbox), "destroy",
-                    G_CALLBACK (gtk_widget_destroyed), &propbox);
-  
+		    G_CALLBACK (gtk_widget_destroyed), &propbox);
+
   notebook = gtk_notebook_new ();
   gtk_container_set_border_width (GTK_CONTAINER (notebook), 5);
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (propbox)->vbox), notebook, 
-                      TRUE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (propbox)->vbox), notebook,
+		      TRUE, TRUE, 0);
 
   /* The configuration page */
   cpage = gtk_vbox_new (FALSE, 18);
@@ -479,7 +482,7 @@ show_properties_dialog (void)
 		    G_CALLBACK (type_selection), NULL);
   fill_typemenu (typemenu);
   gtk_box_pack_start_defaults (GTK_BOX (hbox), typemenu);
-  
+
   frame = games_frame_new (_("Options"));
   gtk_box_pack_start (GTK_BOX (cpage), frame, FALSE, FALSE, 0);
   vbox = gtk_vbox_new (TRUE, 6);
@@ -491,41 +494,47 @@ show_properties_dialog (void)
   gtk_box_pack_start (GTK_BOX (vbox), table, FALSE, FALSE, 0);
 
   chkbox = gtk_check_button_new_with_mnemonic (_("_Use safe moves"));
-  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (chkbox), 
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (chkbox),
 				properties.safe_moves);
   g_signal_connect (G_OBJECT (chkbox), "clicked",
-		    (GtkSignalFunc)safe_cb, NULL);
+		    (GtkSignalFunc) safe_cb, NULL);
   gtk_table_attach (GTK_TABLE (table), chkbox, 0, 1, 0, 1, GTK_FILL, 0, 0, 0);
   gtk_tooltips_set_tip (tooltips, chkbox,
-			_("Prevent some dangerous moves"), 
-			_("Prevent accidental moves that result in getting killed."));
+			_("Prevent some dangerous moves"),
+			_
+			("Prevent accidental moves that result in getting killed."));
 
   chkbox = gtk_check_button_new_with_mnemonic (_("U_se super safe moves"));
-  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (chkbox), properties.super_safe_moves);
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (chkbox),
+				properties.super_safe_moves);
   g_signal_connect (G_OBJECT (chkbox), "clicked",
-		    (GtkSignalFunc)super_safe_cb, NULL);
+		    (GtkSignalFunc) super_safe_cb, NULL);
   gtk_table_attach (GTK_TABLE (table), chkbox, 0, 1, 1, 2, GTK_FILL, 0, 0, 0);
   gtk_tooltips_set_tip (tooltips, chkbox,
-			_("Prevent all dangerous moves"), 
-			_("Prevents all moves that result in getting killed."));
+			_("Prevent all dangerous moves"),
+			_
+			("Prevents all moves that result in getting killed."));
 
   chkbox = gtk_check_button_new_with_mnemonic (_("_Enable sounds"));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (chkbox), properties.sound);
   g_signal_connect (G_OBJECT (chkbox), "clicked",
-		    (GtkSignalFunc)sound_cb, NULL);
+		    (GtkSignalFunc) sound_cb, NULL);
   gtk_table_attach (GTK_TABLE (table), chkbox, 1, 2, 0, 1, GTK_FILL, 0, 0, 0);
   gtk_tooltips_set_tip (tooltips, chkbox,
-			_("Play sounds for major events"), 
-			_("Play sounds for events like winning a level and dying."));
+			_("Play sounds for major events"),
+			_
+			("Play sounds for events like winning a level and dying."));
 
   chkbox = gtk_check_button_new_with_mnemonic (_("E_nable splats"));
-  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (chkbox), properties.splats);
-  g_signal_connect (G_OBJECT (chkbox), "clicked",
-		    (GtkSignalFunc)splat_cb, NULL);
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (chkbox),
+				properties.splats);
+  g_signal_connect (G_OBJECT (chkbox), "clicked", (GtkSignalFunc) splat_cb,
+		    NULL);
   gtk_table_attach (GTK_TABLE (table), chkbox, 1, 2, 1, 2, GTK_FILL, 0, 0, 0);
   gtk_tooltips_set_tip (tooltips, chkbox,
-			_("Play a sound when two robots collide"), 
-			_("Play the most common, and potentially the most annoying, sound."));
+			_("Play a sound when two robots collide"),
+			_
+			("Play the most common, and potentially the most annoying, sound."));
 
   label = gtk_label_new_with_mnemonic (_("Game"));
   gtk_notebook_append_page (GTK_NOTEBOOK (notebook), cpage, label);
@@ -549,7 +558,7 @@ show_properties_dialog (void)
 
   pmapmenu = make_theme_menu ();
   g_signal_connect (G_OBJECT (pmapmenu), "changed",
-                    G_CALLBACK (pmap_selection), NULL);
+		    G_CALLBACK (pmap_selection), NULL);
   gtk_label_set_mnemonic_widget (GTK_LABEL (label), pmapmenu);
 
   gtk_table_attach_defaults (GTK_TABLE (table), pmapmenu, 1, 2, 0, 1);
@@ -558,10 +567,10 @@ show_properties_dialog (void)
   gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
   gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2, GTK_FILL, 0, 0, 0);
 
-  w  = gtk_color_button_new ();
+  w = gtk_color_button_new ();
   gtk_color_button_set_color (GTK_COLOR_BUTTON (w), &properties.bgcolour);
   g_signal_connect (G_OBJECT (w), "color_set",
-                    G_CALLBACK (bg_color_callback), NULL);
+		    G_CALLBACK (bg_color_callback), NULL);
   gtk_label_set_mnemonic_widget (GTK_LABEL (label), w);
 
   gtk_table_attach_defaults (GTK_TABLE (table), w, 1, 2, 1, 2);
@@ -579,7 +588,7 @@ show_properties_dialog (void)
   gtk_container_add (GTK_CONTAINER (frame), vbox);
 
   controls_list = games_controls_list_new ();
-  games_controls_list_add_controls (GAMES_CONTROLS_LIST (controls_list), 
+  games_controls_list_add_controls (GAMES_CONTROLS_LIST (controls_list),
 				    "/apps/gnobots2/preferences/key00",
 				    "/apps/gnobots2/preferences/key01",
 				    "/apps/gnobots2/preferences/key02",
@@ -591,8 +600,7 @@ show_properties_dialog (void)
 				    "/apps/gnobots2/preferences/key04",
 				    "/apps/gnobots2/preferences/key09",
 				    "/apps/gnobots2/preferences/key10",
-				    "/apps/gnobots2/preferences/key11",
-				    NULL);
+				    "/apps/gnobots2/preferences/key11", NULL);
 
   gtk_box_pack_start (GTK_BOX (vbox), controls_list, TRUE, TRUE, 0);
 
@@ -602,17 +610,17 @@ show_properties_dialog (void)
 
   dbut = gtk_button_new_with_mnemonic (_("_Restore Defaults"));
   g_signal_connect (G_OBJECT (dbut), "clicked",
-                    G_CALLBACK (defkey_cb), (gpointer)default_keys);  
+		    G_CALLBACK (defkey_cb), (gpointer) default_keys);
   gtk_box_pack_start (GTK_BOX (hbox), dbut, FALSE, FALSE, 0);
 
   label = gtk_label_new_with_mnemonic (_("Keyboard"));
   gtk_notebook_append_page (GTK_NOTEBOOK (notebook), kpage, label);
 
 
-  g_signal_connect  (G_OBJECT  (propbox), "delete_event",
-                     G_CALLBACK (delete_cb), NULL);
+  g_signal_connect (G_OBJECT (propbox), "delete_event",
+		    G_CALLBACK (delete_cb), NULL);
   g_signal_connect (G_OBJECT (propbox), "response",
-                    G_CALLBACK (apply_cb), NULL);
+		    G_CALLBACK (apply_cb), NULL);
 
   gtk_widget_show_all (propbox);
 }
@@ -621,7 +629,7 @@ show_properties_dialog (void)
 GConfClient *
 get_gconf_client ()
 {
-  if (!gconf_client) 
+  if (!gconf_client)
     gconf_client = gconf_client_get_default ();
   return gconf_client;
 }
@@ -632,7 +640,7 @@ initialize_gconf (int argc, char *argv[])
   gconf_init (argc, argv, NULL);
   gconf_client = get_gconf_client ();
   gconf_client_add_dir (gconf_client, KEY_DIR,
-                        GCONF_CLIENT_PRELOAD_NONE, NULL);
+			GCONF_CLIENT_PRELOAD_NONE, NULL);
 }
 
 /**
@@ -651,14 +659,14 @@ load_properties (void)
   gchar *cname = NULL;
   gint i;
   gchar *str;
-  gchar * bgcolour;
+  gchar *bgcolour;
 
   for (i = 0; i < 12; i++) {
     properties.keys[i] = default_keys[i];
 
     sprintf (buffer, KEY_CONTROL_KEY, i);
 
-    str = gconf_client_get_string (get_gconf_client (), buffer, NULL);    
+    str = gconf_client_get_string (get_gconf_client (), buffer, NULL);
     if (str != NULL) {
       properties.keys[i] = gdk_keyval_from_name (str);
     }
@@ -669,25 +677,26 @@ load_properties (void)
   }
 
   bgcolour = gconf_client_get_string (get_gconf_client (),
-                                      KEY_BACKGROUND_COLOR, NULL);
+				      KEY_BACKGROUND_COLOR, NULL);
   if (bgcolour == NULL)
     bgcolour = g_strdup ("#7590AE");
-  
+
   gdk_color_parse (bgcolour, &properties.bgcolour);
   set_background_color (properties.bgcolour);
-  
-  properties.themename = gconf_client_get_string (get_gconf_client (), 
+
+  properties.themename = gconf_client_get_string (get_gconf_client (),
 						  KEY_THEME, NULL);
   if (properties.themename == NULL)
     properties.themename = ("robots");
 
-  cname = gconf_client_get_string (get_gconf_client (), KEY_CONFIGURATION, NULL);
+  cname =
+    gconf_client_get_string (get_gconf_client (), KEY_CONFIGURATION, NULL);
   if (cname == NULL)
     cname = g_strdup ("classic_robots");
 
   properties.selected_config = 0;
   for (i = 0; i < num_game_configs (); ++i) {
-    if (! strcmp (cname, game_config_name (i))) {
+    if (!strcmp (cname, game_config_name (i))) {
       properties.selected_config = i;
       break;
     }
@@ -695,15 +704,16 @@ load_properties (void)
   g_free (cname);
 
   properties.safe_moves = gconf_client_get_bool (get_gconf_client (),
-                                                 KEY_SAFE_MOVES, NULL);
+						 KEY_SAFE_MOVES, NULL);
   properties.super_safe_moves = gconf_client_get_bool (get_gconf_client (),
-                                                       KEY_SUPER_SAFE_MOVES, NULL);
-  properties.sound = gconf_client_get_bool (get_gconf_client (),
-                                            KEY_ENABLE_SOUND, NULL);
-  properties.splats = gconf_client_get_bool (get_gconf_client (),
-                                             KEY_ENABLE_SPLATS, NULL);
-  properties.show_toolbar = gconf_client_get_bool (get_gconf_client (),
-						   KEY_SHOW_TOOLBAR, NULL);
+						       KEY_SUPER_SAFE_MOVES,
+						       NULL);
+  properties.sound =
+    gconf_client_get_bool (get_gconf_client (), KEY_ENABLE_SOUND, NULL);
+  properties.splats =
+    gconf_client_get_bool (get_gconf_client (), KEY_ENABLE_SPLATS, NULL);
+  properties.show_toolbar =
+    gconf_client_get_bool (get_gconf_client (), KEY_SHOW_TOOLBAR, NULL);
 
   set_game_graphics (properties.themename);
   set_game_config (properties.selected_config);
@@ -713,74 +723,68 @@ load_properties (void)
 }
 
 void
-gconf_set_theme (gchar *value)
+gconf_set_theme (gchar * value)
 {
-  gconf_client_set_string (get_gconf_client (), KEY_THEME,
-                           value, NULL);
+  gconf_client_set_string (get_gconf_client (), KEY_THEME, value, NULL);
 }
 
 static void
 gconf_set_background_color (GdkColor * c)
 {
-  gchar * name;
+  gchar *name;
 
   name = g_strdup_printf ("#%04x%04x%04x", c->red, c->green, c->blue);
-  
+
   gconf_client_set_string (get_gconf_client (), KEY_BACKGROUND_COLOR,
-                           name, NULL);
+			   name, NULL);
 
   g_free (name);
 }
 
 void
-gconf_set_configuration (gchar *value)
+gconf_set_configuration (gchar * value)
 {
   gconf_client_set_string (get_gconf_client (), KEY_CONFIGURATION,
-                           value, NULL);
+			   value, NULL);
 }
 
 void
 gconf_set_use_safe_moves (gboolean value)
 {
-  gconf_client_set_bool (get_gconf_client (), KEY_SAFE_MOVES,
-                         value, NULL);
+  gconf_client_set_bool (get_gconf_client (), KEY_SAFE_MOVES, value, NULL);
 }
 
 void
 gconf_set_use_super_safe_moves (gboolean value)
 {
   gconf_client_set_bool (get_gconf_client (), KEY_SUPER_SAFE_MOVES,
-                         value, NULL);
+			 value, NULL);
 }
 
 void
 gconf_set_enable_sound (gboolean value)
 {
-  gconf_client_set_bool (get_gconf_client (), KEY_ENABLE_SOUND,
-                         value, NULL);
+  gconf_client_set_bool (get_gconf_client (), KEY_ENABLE_SOUND, value, NULL);
 }
 
 void
 gconf_set_enable_splats (gboolean value)
 {
-  gconf_client_set_bool (get_gconf_client (), KEY_ENABLE_SPLATS,
-                         value, NULL);
+  gconf_client_set_bool (get_gconf_client (), KEY_ENABLE_SPLATS, value, NULL);
 }
 
 void
 gconf_set_show_toolbar (gboolean value)
 {
-  gconf_client_set_bool (get_gconf_client (), KEY_SHOW_TOOLBAR,
-			 value, NULL);
+  gconf_client_set_bool (get_gconf_client (), KEY_SHOW_TOOLBAR, value, NULL);
 }
 
 void
-gconf_set_control_key (gint i, gchar *value)
+gconf_set_control_key (gint i, gchar * value)
 {
   gchar *buffer;
   buffer = g_strdup_printf (KEY_CONTROL_KEY, i);
-  gconf_client_set_string (get_gconf_client (), buffer,
-                           value, NULL);
+  gconf_client_set_string (get_gconf_client (), buffer, value, NULL);
   g_free (buffer);
 }
 
@@ -796,12 +800,12 @@ gconf_set_control_key (gint i, gchar *value)
 gboolean
 save_properties (void)
 {
-  gint   i;
+  gint i;
 
   for (i = 0; i < 12; i++) {
     gconf_set_control_key (i, gdk_keyval_name (properties.keys[i]));
   }
-  
+
   gconf_set_theme (properties.themename);
   gconf_set_configuration (game_config_name (properties.selected_config));
   gconf_set_use_safe_moves (properties.safe_moves);
@@ -906,7 +910,7 @@ properties_show_toolbar (void)
 gboolean
 properties_set_config (gint n)
 {
-  if (! set_game_config (n))
+  if (!set_game_config (n))
     return FALSE;
 
   properties.selected_config = n;
