@@ -30,6 +30,11 @@ ERROR_HIGHLIGHT_COLOR = (1.0,0,0)
 
 BASE_SIZE = 35 # The "normal" size of a box (in pixels)
 
+# And the standard font-sizes -- these should fit nicely with the
+# BASE_SIZE
+BASE_FONT_SIZE = pango.SCALE * 13 
+NOTE_FONT_SIZE = pango.SCALE * 6
+
 BORDER_WIDTH = 9.0 # The size of space we leave for a box
 
 BORDER_LINE_WIDTH = 4 # The size of the line we draw around a selected box
@@ -138,9 +143,9 @@ class NumberBox (gtk.Widget):
         gtk.Widget.__init__(self)
         self.upper = upper
         self.font = self.style.font_desc
-        self.font.set_size(pango.SCALE*13)
+        self.font.set_size(BASE_FONT_SIZE)
         self.note_font = self.font.copy()
-        self.note_font.set_size(pango.SCALE*6)
+        self.note_font.set_size(NOTE_FONT_SIZE)
         self.set_property('can-focus',True)
         self.set_property('events',gtk.gdk.ALL_EVENTS_MASK)
         self.connect('button-press-event',self.button_press_cb)
@@ -402,10 +407,13 @@ class NumberBox (gtk.Widget):
         # that gtk+ will actually give this size to the widget
 
         # In this case, we say that we want to be as big as the
-        # text is, plus a little border around it.
+        # text is, and a square
         width, height = self._layout.get_size()
-        requisition.width = (width / pango.SCALE)+(BORDER_LINE_WIDTH+BORDER_WIDTH)*2
-        requisition.height = height / pango.SCALE+(BORDER_LINE_WIDTH+BORDER_WIDTH)*2
+        if width > height:
+            side = width/pango.SCALE
+        else:
+            side = height/pango.SCALE
+        requisition.width = side; requisition.height = side
 
     def do_size_allocate(self, allocation):
         # The do_size_allocate is called by when the actual size is known
@@ -790,16 +798,22 @@ class ParallelDict (dict):
                 self[i].add(k)
             else:
                 dict.__setitem__(self,i,set([k]))
-            
+
     def __delitem__ (self, k):
         v=self[k]
         dict.__delitem__(self,k)
         for i in v:
             if i==k: continue
-            if k in self[i]: self[i].remove(k)
-            if not self[i]:
-                dict.__delitem__(self,i)
-
+            if self.has_key(i):
+                # Make sure we have a reference to i. If we don't
+                # something has gone wrong... but according to bug
+                # 385937 this has gone wrong at least once, so we'd
+                # better check for it.
+                if k in self[i]: self[i].remove(k)
+                if not self[i]:
+                    # If k was the last value in the list of values
+                    # for i, then we delete i from our dictionary
+                    dict.__delitem__(self,i)
 
 class SudokuGameDisplay (SudokuNumberGrid, gobject.GObject):
 
@@ -941,11 +955,10 @@ class SudokuGameDisplay (SudokuNumberGrid, gobject.GObject):
         for x in range(self.group_size):
             for y in range(self.group_size):
                 if not self.grid.virgin._get_(x,y):
-                    val = self.grid._get_(x,y)
+                    val = self.__entries__[(x,y)].get_value() # get the value from the user-visible grid, 
                     if val:
                         removed.append((x,y,val,self.trackers_for_point(x,y,val)))
-                        self.remove(x,y)
-                        self.grid.remove(x,y)
+                        self.remove(x,y,do_removal=True)
         return removed
 
     def clear_notes (self, clear_args={'top_text':'','bottom_text':''}):
@@ -1065,6 +1078,17 @@ class SudokuGameDisplay (SudokuNumberGrid, gobject.GObject):
                 self.__entries__[conflict].set_error_highlight(True)
             self.__error_pairs__[(err.x,err.y)]=conflicts
 
+    def add_value_to_ui (self, x, y, val, trackers=[]):
+        """Add our value back to our grid come hell or high water.
+
+        We add our value -- if there is an error, we make the value
+        appear as if the user had typed it; i.e. it will show up with
+        error highlighting."""
+        try:
+            self.add_value(x, y, val, trackers=[])
+        except sudoku.ConflictError:
+            self.entry_validate(self.__entries__[(x,y)])
+
     @simple_debug
     def add_value (self, x, y, val, trackers=[]):
         """Add value val at position x,y.
@@ -1101,6 +1125,8 @@ class SudokuGameDisplay (SudokuNumberGrid, gobject.GObject):
         If do_removal, remove it from our underlying grid as well.
         """        
         e=self.__entries__[(x,y)]
+        if do_removal and self.grid and self.grid._get_(x,y):
+            self.grid.remove(x,y)
         if self.__error_pairs__.has_key((x,y)):
             e.set_error_highlight(False)
             errors_removed = self.__error_pairs__[(x,y)]
@@ -1114,7 +1140,10 @@ class SudokuGameDisplay (SudokuNumberGrid, gobject.GObject):
                     # added to our internal grid, in which case we'd
                     # better make sure it is...
                     if not self.grid._get_(linked_entry.x,linked_entry.y):
-                        self.add_value(linked_entry.x,linked_entry.y,linked_entry.get_value()) 
+                        # entry_validate will add the value to our
+                        # internal grid if there are no other
+                        # conflicts
+                        self.entry_validate(linked_entry)
         # remove trackers
         for t in self.trackers_for_point(x,y):
             remove = []
@@ -1125,8 +1154,6 @@ class SudokuGameDisplay (SudokuNumberGrid, gobject.GObject):
                 self.trackers[t].remove(r)
         if e.get_text(): e.set_value(0)
         e.unset_color()
-        if do_removal and self.grid:
-            self.grid.remove(x,y)
 
     @simple_debug
     def auto_fill (self):
@@ -1288,6 +1315,5 @@ if __name__ == '__main__':
     test_sudoku_game()
 
         
-        
             
     
